@@ -1,11 +1,9 @@
 import importlib.metadata
 
-import cv2
+import cv2  # type: ignore
 
 VERSION = importlib.metadata.version("videoxt")
 
-IS_TERMINAL = False
-
 VALID_ROTATE_VALUES = (0, 90, 180, 270)
 
 ROTATION_MAP = {
@@ -14,6 +12,15 @@ ROTATION_MAP = {
     270: cv2.ROTATE_90_COUNTERCLOCKWISE,
 }
 
+
+VALID_AUDIO_FORMATS = (
+    "m4a",
+    "mp3",
+    "ogg",
+    "wav",
+)
+
+
 VALID_IMAGE_FORMATS = (
     "bmp",
     "dib",
@@ -25,21 +32,12 @@ VALID_IMAGE_FORMATS = (
     "webp",
 )
 
+
 EMOJI_MAP = {
     "video": "VIDEO \N{FILM PROJECTOR}",
     "extraction": "EXTRACTION \N{TOOTH}",
-    "image": "IMAGES \N{CAMERA WITH FLASH}",
+    "audio": "AUDIO \N{SPEAKER WITH THREE SOUND WAVES}",
+    "clip": "CLIP \N{FILM PROJECTOR}",
+    "frames": "FRAMES \N{CAMERA WITH FLASH}",
     "gif": "GIF \N{FILM FRAMES}",
-    "resize_small": "\N{BUG}",
-    "resize_normal": "\N{GOAT}",
-    "resize_large": "\N{WHALE}",
-    "speed_slow": "\N{TURTLE}",
-    "speed_normal": "\N{MONKEY}",
-    "speed_fast": "\N{RABBIT}",
-    "stop": "\N{RAISED HAND}",
-    "start": "\N{CLAPPER BOARD}",
-    0: "\N{UPWARDS BLACK ARROW}",
-    90: "\N{BLACK RIGHTWARDS ARROW}",
-    180: "\N{DOWNWARDS BLACK ARROW}",
-    270: "\N{LEFTWARDS BLACK ARROW}",
 }
